KingPaint

Provide the simplest way to paint interactively.

This lib is used to learn 2 dimension analytic geometry and plane geometry.

The main function such as: triangle, circle, conic, line, etc.

You can extend this lib easy.

You can learn this lib at: https://gitee.com/cai-jinhang/king-paint-examples
